==> foundation-ui-components-1.10.0-cx130-872.1.tgz: package/src/common/card/NsHeroCardLevel2.tsx <==
import { NsImage } from '../';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel2Props = {
    brandName: string;
    cardTitle: string;
    cardDescription: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        '.content': {
            height: '100%',
            padding: '50px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.image': {
            width: 'auto',
            height: '100%',
            display: 'block',
        },
        '.brand-container': {
            backgroundColor: '#fff',
            width: 'fit-content',
            paddingLeft: '10px',
            paddingRight: '10px',
        },
        '.body-title': {
            fontSize: '36px',
            lineHeight: '44px',
            marginBottom: '5px',
        },
        '.body-text': {
            fontSize: '18px',
            fontWeight: 700,
            marginBottom: '5px',
        },
        '@media (max-width: 768px)': {
            '.content': {
                padding: '5%',
            },
            '.body-title': {
                fontSize: '18px',
                lineHeight: '44px',
                marginBottom: '5px',
            },
            '.body-text': {
                fontSize: '12px',
                fontWeight: 700,
                marginBottom: '5px',
            },
        },
    };
});

const NsHeroCardLevel2 = ({
    brandName,
    cardTitle,
    cardDescription,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
}: NsHeroCardLevel2Props) => {
    return (
        <CardContainer className={className} data-testid="hero-card-level-2">
            <div className="image">
                <NsImage height={'auto'} width={'100%'} alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <div className="brand-container">
                    <article>{brandName}</article>
                </div>
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                <div>{button ? <CardButton {...button} /> : null}</div>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel2;

==> foundation-ui-components-1.28.0-cx130-1216.1.tgz: package/src/common/card/NsHeroCardLevel2.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';
import { BynderMedia } from '../image/BynderMedia';
import { BynderImageDataType } from '../image/types';

type NsHeroCardLevel2Props = {
    brandName: string;
    cardTitle: string;
    cardDescription: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: '236px',
        maxWidth: '536px',
        '.content': {
            height: '100%',
            padding: '50px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.bg-image': {
            objectFit: 'cover',
        },
        '.brand-container': {
            backgroundColor: '#fff',
            width: 'fit-content',
            paddingLeft: '10px',
            paddingRight: '10px',
        },
        '.body-title': {
            fontSize: '26px',
            lineHeight: '44px',
            marginBottom: '5px',
        },
        '.body-text': {
            fontSize: '12px',
            fontWeight: 700,
            marginBottom: '5px',
        },
        '@media (max-width:768px)': {
            '.content': {
                padding: '5%',
            },
        },
    };
});

const NsHeroCardLevel2 = ({
    brandName,
    cardTitle,
    cardDescription,
    backgroundImageDetail,
    button,
    className,
}: NsHeroCardLevel2Props) => {
    return (
        <CardContainer className={className} data-testid="hero-card-level-2">
            <BynderMedia className="bg-image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <div className="brand-container">
                    <article>{brandName}</article>
                </div>
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                <div>{button ? <CardButton {...button} /> : null}</div>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel2;
